==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkCameraRepresentation.java <==
// java wrapper for vtkCameraRepresentation object
//

package vtk;
import vtk.*;

public class vtkCameraRepresentation extends vtkBorderRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCamera_2(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_2(id0); }

  private native long GetCamera_3();
  public vtkCamera GetCamera() {
    long temp = GetCamera_3();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetInterpolator_4(vtkCameraInterpolator id0);
  public void SetInterpolator(vtkCameraInterpolator id0)
    { SetInterpolator_4(id0); }

  private native long GetInterpolator_5();
  public vtkCameraInterpolator GetInterpolator() {
    long temp = GetInterpolator_5();

    if (temp == 0) return null;
    return (vtkCameraInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetNumberOfFrames_6(int id0);
  public void SetNumberOfFrames(int id0)
    { SetNumberOfFrames_6(id0); }

  private native int GetNumberOfFramesMinValue_7();
  public int GetNumberOfFramesMinValue()
    { return GetNumberOfFramesMinValue_7(); }

  private native int GetNumberOfFramesMaxValue_8();
  public int GetNumberOfFramesMaxValue()
    { return GetNumberOfFramesMaxValue_8(); }

  private native int GetNumberOfFrames_9();
  public int GetNumberOfFrames()
    { return GetNumberOfFrames_9(); }

  private native long GetProperty_10();
  public vtkProperty2D GetProperty() {
    long temp = GetProperty_10();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void AddCameraToPath_11();
  public void AddCameraToPath()
    { AddCameraToPath_11(); }

  private native void AnimatePath_12(vtkRenderWindowInteractor id0);
  public void AnimatePath(vtkRenderWindowInteractor id0)
    { AnimatePath_12(id0); }

  private native void InitializePath_13();
  public void InitializePath()
    { InitializePath_13(); }

  private native void BuildRepresentation_14();
  public void BuildRepresentation()
    { BuildRepresentation_14(); }

  private native void GetSize_15(double id0[]);
  public void GetSize(double id0[])
    { GetSize_15(id0); }

  private native void GetActors2D_16(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_16(id0); }

  private native void ReleaseGraphicsResources_17(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  private native int RenderTranslucentPolygonalGeometry_20(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_20(id0); }

  private native int HasTranslucentPolygonalGeometry_21();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_21(); }

  public vtkCameraRepresentation() { super(); }

  public vtkCameraRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-armv6h.pkg.tar.xz: vtk/vtkCameraRepresentation.java <==
// java wrapper for vtkCameraRepresentation object
//

package vtk;
import vtk.*;

public class vtkCameraRepresentation extends vtkBorderRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCamera_2(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_2(id0); }

  private native long GetCamera_3();
  public vtkCamera GetCamera() {
    long temp = GetCamera_3();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInterpolator_4(vtkCameraInterpolator id0);
  public void SetInterpolator(vtkCameraInterpolator id0)
    { SetInterpolator_4(id0); }

  private native long GetInterpolator_5();
  public vtkCameraInterpolator GetInterpolator() {
    long temp = GetInterpolator_5();

    if (temp == 0) return null;
    return (vtkCameraInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetNumberOfFrames_6(int id0);
  public void SetNumberOfFrames(int id0)
    { SetNumberOfFrames_6(id0); }

  private native int GetNumberOfFramesMinValue_7();
  public int GetNumberOfFramesMinValue()
    { return GetNumberOfFramesMinValue_7(); }

  private native int GetNumberOfFramesMaxValue_8();
  public int GetNumberOfFramesMaxValue()
    { return GetNumberOfFramesMaxValue_8(); }

  private native int GetNumberOfFrames_9();
  public int GetNumberOfFrames()
    { return GetNumberOfFrames_9(); }

  private native long GetProperty_10();
  public vtkProperty2D GetProperty() {
    long temp = GetProperty_10();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AddCameraToPath_11();
  public void AddCameraToPath()
    { AddCameraToPath_11(); }

  private native void AnimatePath_12(vtkRenderWindowInteractor id0);
  public void AnimatePath(vtkRenderWindowInteractor id0)
    { AnimatePath_12(id0); }

  private native void InitializePath_13();
  public void InitializePath()
    { InitializePath_13(); }

  private native void BuildRepresentation_14();
  public void BuildRepresentation()
    { BuildRepresentation_14(); }

  private native void GetSize_15(double id0[]);
  public void GetSize(double id0[])
    { GetSize_15(id0); }

  private native void GetActors2D_16(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_16(id0); }

  private native void ReleaseGraphicsResources_17(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  private native int RenderTranslucentPolygonalGeometry_20(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_20(id0); }

  private native int HasTranslucentPolygonalGeometry_21();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_21(); }

  public vtkCameraRepresentation() { super(); }

  public vtkCameraRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
